@@ -44,9 +44,9 @@ namespace aqua
                 channels[i].resize((lines + 1) * 30);
         }
 
-        image::Image<uint16_t> AMSUA2Reader::getChannel(int channel)
+        image::Image AMSUA2Reader::getChannel(int channel)
         {
-            return image::Image<uint16_t>(channels[channel].data(), 30, lines, 1);
+            return image::Image(channels[channel].data(), 16, 30, lines, 1);
         }
     } // namespace amsu
 } // namespace aqua
\ No newline at end of file
