@@ -17,8 +17,8 @@ namespace aqua
 
         std::ifstream data_in;
         std::ofstream data_out;
-        std::atomic<size_t> filesize;
-        std::atomic<size_t> progress;
+        std::atomic<uint64_t> filesize;
+        std::atomic<uint64_t> progress;
 
     public:
         AquaDBDecoderModule(std::string input_file, std::string output_file_hint, nlohmann::json parameters);
