@@ -6,6 +6,6 @@ namespace eos
 {
     namespace modis
     {
-        void modis_match_detector_histograms(image::Image<uint16_t> &img, int ndetx, int ndety);
+        void modis_match_detector_histograms(image::Image &img, int ndetx, int ndety);
     };
 };
\ No newline at end of file
