@@ -1,7 +1,7 @@
 #include "module_eos_instruments.h"
 #include <fstream>
-#include "common/ccsds/ccsds_weather/demuxer.h"
-#include "common/ccsds/ccsds_weather/vcdu.h"
+#include "common/ccsds/ccsds_aos/demuxer.h"
+#include "common/ccsds/ccsds_aos/vcdu.h"
 #include "logger.h"
 #include <filesystem>
 #include "imgui/imgui.h"
@@ -51,15 +51,15 @@ namespace eos
             uint8_t cadu[1024];
 
             // Demuxers
-            ccsds::ccsds_weather::Demuxer demuxer_vcid3;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid10;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid15;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid20;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid25;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid26;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid30;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid35;
-            ccsds::ccsds_weather::Demuxer demuxer_vcid42;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid3;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid10;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid15;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid20;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid25;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid26;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid30;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid35;
+            ccsds::ccsds_aos::Demuxer demuxer_vcid42;
 
             while (!data_in.eof())
             {
@@ -67,7 +67,7 @@ namespace eos
                 data_in.read((char *)&cadu, 1024);
 
                 // Parse this transport frame
-                ccsds::ccsds_weather::VCDU vcdu = ccsds::ccsds_weather::parseVCDU(cadu);
+                ccsds::ccsds_aos::VCDU vcdu = ccsds::ccsds_aos::parseVCDU(cadu);
 
                 if (d_satellite == TERRA)
                 {
@@ -125,10 +125,10 @@ namespace eos
                     }
                     else if (vcdu.vcid == 15) // CERES FM-4
                     {
-                        std::vector<ccsds::CCSDSPacket> ccsdsFrames = demuxer_vcid15.work(cadu);
-                        for (ccsds::CCSDSPacket &pkt : ccsdsFrames)
-                            if (pkt.header.apid == 157)
-                                ceres_fm4_reader.work(pkt);
+                       // std::vector<ccsds::CCSDSPacket> ccsdsFrames = demuxer_vcid15.work(cadu);
+                       // for (ccsds::CCSDSPacket &pkt : ccsdsFrames)
+                           // if (pkt.header.apid == 157)
+                            //    ceres_fm4_reader.work(pkt);
                     }
                 }
                 else if (d_satellite == AURA)
@@ -166,18 +166,21 @@ namespace eos
             else if (d_satellite == AURA)
                 dataset.satellite_name = "Aura";
 
+            if (d_satellite == AQUA || d_satellite == TERRA) // MODIS
+                dataset.timestamp = get_median(modis_reader.timestamps_1000);
+            else
+                dataset.timestamp = time(0);
+
             std::optional<satdump::TLE> satellite_tle;
             if (d_satellite == AQUA)
-                satellite_tle = satdump::general_tle_registry.get_from_norad(27424);
+                satellite_tle = satdump::general_tle_registry.get_from_norad_time(27424, dataset.timestamp);
             else if (d_satellite == TERRA)
-                satellite_tle = satdump::general_tle_registry.get_from_norad(25994);
+                satellite_tle = satdump::general_tle_registry.get_from_norad_time(25994, dataset.timestamp);
             else if (d_satellite == AURA)
-                satellite_tle = satdump::general_tle_registry.get_from_norad(28376);
+                satellite_tle = satdump::general_tle_registry.get_from_norad_time(28376, dataset.timestamp);
 
             if (d_satellite == AQUA || d_satellite == TERRA) // MODIS
             {
-                dataset.timestamp = get_median(modis_reader.timestamps_1000);
-
                 modis_status = SAVING;
                 std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/MODIS";
 
@@ -245,7 +248,7 @@ namespace eos
                     else if (i == 6)
                         modis_products.images.push_back({"MODIS-13H", "13H", image});
                     else if (i == 7)
-                        modis_products.images.push_back({"MODIS-14L", "13L", image});
+                        modis_products.images.push_back({"MODIS-14L", "14L", image});
                     else if (i == 8)
                         modis_products.images.push_back({"MODIS-14H", "14H", image});
                     else
@@ -308,7 +311,8 @@ namespace eos
                 airs_hd_products.bit_depth = 16;
                 airs_hd_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_IFOV;
                 airs_hd_products.set_tle(satellite_tle);
-                // airs_hd_products.set_timestamps(airs_reader.timestamps_ifov);
+                airs_hd_products.set_timestamps(airs_reader.timestamps_ifov);
+                airs_hd_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/aqua_airs.json")));
 
                 for (int i = 0; i < 4; i++)
                     airs_hd_products.images.push_back({"AIRS-HD-" + std::to_string(i + 1), std::to_string(i + 1), airs_reader.getHDChannel(i)});
@@ -321,9 +325,10 @@ namespace eos
                 airs_products.has_timestamps = true;
                 airs_products.bit_depth = 16;
                 airs_products.save_as_matrix = true;
-                airs_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
+                airs_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_IFOV;
                 airs_products.set_tle(satellite_tle);
-                // airs_products.set_timestamps(airs_reader.timestamps_ifov);
+                airs_products.set_timestamps(airs_reader.timestamps_ifov);
+                airs_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/aqua_airs.json")));
 
                 for (int i = 0; i < 2666; i++)
                     airs_products.images.push_back({"AIRS-" + std::to_string(i + 1), std::to_string(i + 1), airs_reader.getChannel(i)});
@@ -379,21 +384,53 @@ namespace eos
                 logger->info("Lines (FM3) : " + std::to_string(ceres_fm3_reader.lines));
                 logger->info("Lines (FM4) : " + std::to_string(ceres_fm4_reader.lines));
 
-                auto img = ceres_fm3_reader.getImage(0);
-                image::save_img(img, directory + "/CERES1-SHORTWAVE");
-                img = ceres_fm3_reader.getImage(1);
-                image::save_img(img, directory + "/CERES1-LONGWAVE");
-                img = ceres_fm3_reader.getImage(2);
-                image::save_img(img, directory + "/CERES1-TOTAL");
-                ceres_fm3_status = DONE;
+                {
+                    std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/CERES-FM3";
 
-                img = ceres_fm4_reader.getImage(0);
-                image::save_img(img, directory + "/CERES2-SHORTWAVE");
-                img = ceres_fm4_reader.getImage(1);
-                image::save_img(img, directory + "/CERES2-LONGWAVE");
-                img = ceres_fm4_reader.getImage(2);
-                image::save_img(img, directory + "/CERES2-TOTAL");
-                ceres_fm4_status = DONE;
+                    if (!std::filesystem::exists(directory))
+                        std::filesystem::create_directory(directory);
+
+                    satdump::ImageProducts ceres_products;
+                    ceres_products.instrument_name = "ceres";
+                    ceres_products.has_timestamps = true;
+                    ceres_products.set_tle(satellite_tle);
+                    ceres_products.bit_depth = 16;
+                    ceres_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
+                    ceres_products.set_timestamps(ceres_fm3_reader.timestamps);
+                    ceres_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/aqua_ceres_fm3.json")));
+
+                    ceres_products.images.push_back({"CERES-LONGWAVE", "l", ceres_fm3_reader.getImage(0)});
+                    ceres_products.images.push_back({"CERES-SHORTWAVE", "s", ceres_fm3_reader.getImage(1)});
+                    ceres_products.images.push_back({"CERES-TOTAL", "t", ceres_fm3_reader.getImage(2)});
+
+                    ceres_products.save(directory);
+                    dataset.products_list.push_back("CERES-FM3");
+                    ceres_fm3_status = DONE;
+                }
+
+                {
+                    std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/CERES-FM4";
+
+                    if (!std::filesystem::exists(directory))
+                        std::filesystem::create_directory(directory);
+
+                    satdump::ImageProducts ceres_products;
+                    ceres_products.instrument_name = "ceres";
+                    ceres_products.has_timestamps = true;
+                    ceres_products.set_tle(satellite_tle);
+                    ceres_products.bit_depth = 16;
+                    ceres_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
+                    ceres_products.set_timestamps(ceres_fm4_reader.timestamps);
+                    ceres_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/aqua_ceres_fm4.json")));
+
+                    ceres_products.images.push_back({"CERES-LONGWAVE", "l", ceres_fm4_reader.getImage(0)});
+                    ceres_products.images.push_back({"CERES-SHORTWAVE", "s", ceres_fm4_reader.getImage(1)});
+                    ceres_products.images.push_back({"CERES-TOTAL", "t", ceres_fm4_reader.getImage(2)});
+
+                    ceres_products.save(directory);
+                    dataset.products_list.push_back("CERES-FM4");
+                    ceres_fm3_status = DONE;
+                }
             }
 
             if (d_satellite == AURA) // OMI
@@ -419,9 +456,9 @@ namespace eos
                 image::save_img(img, directory + "/OMI-VIS-2");
 
                 image::Image imageAll1 = image::make_manyimg_composite(33, 24, 792, [this](int c)
-                                                                         { return omi_1_reader.getChannel(c); });
+                                                                       { return omi_1_reader.getChannel(c); });
                 image::Image imageAll2 = image::make_manyimg_composite(33, 24, 792, [this](int c)
-                                                                         { return omi_2_reader.getChannel(c); });
+                                                                       { return omi_2_reader.getChannel(c); });
                 image::save_img(imageAll1, directory + "/OMI-ALL-1");
                 image::save_img(imageAll2, directory + "/OMI-ALL-2");
                 omi_status = DONE;
