@@ -20,7 +20,7 @@ namespace fengyun3
             int lines;
             std::vector<double> timestamps;
             void work(ccsds::CCSDSPacket &packet);
-            image::Image<uint16_t> getChannel();
+            image::Image getChannel();
         };
     }
 }
\ No newline at end of file
