@@ -19,7 +19,7 @@ namespace fengyun3
             ~MWRIReader();
             int lines;
             void work(std::vector<uint8_t> &packet);
-            image::Image<uint16_t> getChannel(int channel);
+            image::Image getChannel(int channel);
 
             std::vector<double> timestamps;
         };
