@@ -1,9 +1,14 @@
 #pragma once
 
 #include "core/module.h"
+#include "dcs/dcs_decoder.h"
 #include "data/lrit_data.h"
 #include "common/lrit/lrit_file.h"
 #include "common/lrit/lrit_productizer.h"
+#include "goes/crc32.h"
+
+#include <set>
+#include <deque>
 
 extern "C"
 {
@@ -22,8 +27,9 @@ namespace goes
 
             bool write_images;
             bool write_emwin;
-            bool write_messages;
+            bool parse_dcs;
             bool write_dcs;
+            bool write_messages;
             bool write_unknown;
             bool write_lrit;
 
@@ -34,6 +40,15 @@ namespace goes
 
             std::string directory;
 
+            bool is_gui = false;
+            CRC32 dcs_crc32;
+            std::mutex ui_dcs_mtx;
+            std::shared_ptr<DCSMessage> focused_dcs_message = nullptr;
+            std::deque<std::shared_ptr<DCSMessage>> ui_dcs_messages;
+            std::map<std::string, std::string> shef_codes;
+            std::map<uint32_t, std::shared_ptr<DCP>> dcp_list;
+            std::set<uint32_t> filtered_dcps;
+
             enum CustomFileParams
             {
                 RICE_COMPRESSED,
@@ -58,6 +73,10 @@ namespace goes
             void processLRITFile(::lrit::LRITFile &file);
             void saveLRITFile(::lrit::LRITFile &file, std::string path);
 
+            void initDCS();
+            bool processDCS(uint8_t *data, size_t size);
+            void drawDCSUI();
+
             ::lrit::LRITProductizer productizer;
 
             void saveImageP(GOESxRITProductMeta meta, image::Image &img);
