@@ -1,11 +1,11 @@
 #include "module_jason3_instruments.h"
 #include <fstream>
-#include "common/ccsds/ccsds_standard/vcdu.h"
+#include "common/ccsds/ccsds_tm/vcdu.h"
 #include "logger.h"
 #include <filesystem>
 #include "imgui/imgui.h"
 #include "common/utils.h"
-#include "common/ccsds/ccsds_standard/demuxer.h"
+#include "common/ccsds/ccsds_tm/demuxer.h"
 #include "common/image/io.h"
 
 #include <thread>
@@ -30,8 +30,8 @@ namespace jason3
             uint8_t cadu[1279];
 
             // Demuxers
-            ccsds::ccsds_standard::Demuxer demuxer_vcid1(1101, false, 2, 4);
-            ccsds::ccsds_standard::Demuxer demuxer_vcid2(1101, false, 2, 4);
+            ccsds::ccsds_tm::Demuxer demuxer_vcid1(1101, false, 2, 4);
+            ccsds::ccsds_tm::Demuxer demuxer_vcid2(1101, false, 2, 4);
 
             while (!data_in.eof())
             {
@@ -39,7 +39,7 @@ namespace jason3
                 data_in.read((char *)&cadu, 1279);
 
                 // Parse this transport frame
-                ccsds::ccsds_standard::VCDU vcdu = ccsds::ccsds_standard::parseVCDU(cadu);
+                ccsds::ccsds_tm::VCDU vcdu = ccsds::ccsds_tm::parseVCDU(cadu);
 
                 if (vcdu.vcid == 1) // AMR-2, Poseidon
                 {
