@@ -11,8 +11,8 @@ namespace ldcm
         class LDCMInstrumentsDecoderModule : public ProcessingModule
         {
         protected:
-            std::atomic<size_t> filesize;
-            std::atomic<size_t> progress;
+            std::atomic<uint64_t> filesize;
+            std::atomic<uint64_t> progress;
 
             // Readers
             tirs::TIRSReader tirs_reader1;
