@@ -30,12 +30,13 @@ namespace meteor
                 uint16_t QFM;
                 uint8_t QF;
                 bool valid;
-                uint8_t lines[8][14 * 8];
+                bool partial;
+                uint8_t lines[8][14 * 8] = {{0}};
 
                 bool isValid();
 
                 Segment();
-                Segment(uint8_t *data, int length, bool meteorm2x_mode);
+                Segment(uint8_t *data, int length, bool partial, bool meteorm2x_mode);
                 ~Segment();
 
                 void decode(uint8_t *data, int length);
