@@ -18,7 +18,8 @@ namespace meteor
     namespace instruments
     {
         MeteorInstrumentsDecoderModule::MeteorInstrumentsDecoderModule(std::string input_file, std::string output_file_hint, nlohmann::json parameters)
-            : ProcessingModule(input_file, output_file_hint, parameters)
+            : ProcessingModule(input_file, output_file_hint, parameters),
+            bism_reader(getValueOrDefault<int>(parameters["year_override"], -1))
         {
         }
 
@@ -40,21 +41,11 @@ namespace meteor
             def::SimpleDeframer mtvza_deframer2(0x38fb456a, 32, 248 * 8, 0, true);
             def::SimpleDeframer bism_deframer(0x71DE2CD8, 32, 88 * 8, 0, true);
 
-            time_t current_time = d_parameters.contains("start_timestamp")
-                                      ? (d_parameters["start_timestamp"].get<double>() != -1
-                                             ? d_parameters["start_timestamp"].get<double>()
-                                             : time(0))
-                                      : time(0);
-
-            time_t currentDay = current_time + 3 * 3600.0;       // Moscow Time
-            time_t dayValue = currentDay - (currentDay % 86400); // Requires the day to be known from another source
-
             std::vector<double> msumr_timestamps;
             std::vector<uint8_t> msumr_ids;
 
             nlohmann::json msu_mr_telemetry;
-
-            // std::ofstream file_out("idk_bism.bin");
+            nlohmann::json msu_mr_telemetry_calib;
 
             while (!data_in.eof())
             {
@@ -65,6 +56,20 @@ namespace meteor
                 std::vector<std::vector<uint8_t>> mtvza_frames, mtvza_frames2;
                 std::vector<std::vector<uint8_t>> bism_frames;
 
+                // BIS-M Deframing
+                {
+                    std::vector<uint8_t> bism_data;
+                    bism_data.insert(bism_data.end(), &cadu[7 - 1], &cadu[7 - 1] + 4);
+                    bism_data.insert(bism_data.end(), &cadu[263 - 1], &cadu[263 - 1] + 4);
+                    bism_data.insert(bism_data.end(), &cadu[519 - 1], &cadu[519 - 1] + 4);
+                    bism_data.insert(bism_data.end(), &cadu[775 - 1], &cadu[775 - 1] + 4);
+                    bism_frames = bism_deframer.work(bism_data.data(), bism_data.size());
+                }
+
+                // BIS-M Processing
+                for (std::vector<uint8_t> &frame : bism_frames)
+                    bism_reader.work(frame.data());
+
                 // MSU-MR Deframing
                 {
                     std::vector<uint8_t> msu_mr_data;
@@ -79,13 +84,23 @@ namespace meteor
                 for (std::vector<uint8_t> msumr_frame : msumr_frames)
                 {
                     msumr_reader.work(msumr_frame.data());
-                    double timestamp = dayValue + (msumr_frame[8]) * 3600.0 + (msumr_frame[9]) * 60.0 + (msumr_frame[10] + 0.0) + double(msumr_frame[11] / 255.0);
-                    timestamp -= 3 * 3600.0;
-                    msumr_timestamps.push_back(timestamp);
-                    mtvza_reader.latest_msumr_timestamp = mtvza_reader2.latest_msumr_timestamp = timestamp; // MTVZA doesn't have timestamps of its own, so use MSU-MR's
-                    msumr_ids.push_back(msumr_frame[12] >> 4);
 
-                    parseMSUMRTelemetry(msu_mr_telemetry, msumr_timestamps.size() - 1, msumr_frame.data());
+                    time_t bism_day = bism_reader.get_last_day_moscow();
+                    if (bism_day != 0)
+                    {
+                        double timestamp = bism_day + (msumr_frame[8]) * 3600.0 + (msumr_frame[9]) * 60.0 + (msumr_frame[10] + 0.0) + double(msumr_frame[11] / 255.0);
+                        timestamp -= 3 * 3600.0;
+                        msumr_timestamps.push_back(timestamp);
+                        mtvza_reader.latest_msumr_timestamp = mtvza_reader2.latest_msumr_timestamp = timestamp; // MTVZA doesn't have timestamps of its own, so use MSU-MR's
+                    }
+                    else
+                    {
+                        msumr_timestamps.push_back(-1);
+                        mtvza_reader.latest_msumr_timestamp = mtvza_reader2.latest_msumr_timestamp = -1;
+                    }
+
+                    msumr_ids.push_back(msumr_frame[12] >> 4);
+                    parseMSUMRTelemetry(msu_mr_telemetry, msu_mr_telemetry_calib, msumr_timestamps.size() - 1, msumr_frame.data());
                 }
 
                 // MTVZA Deframing
@@ -105,22 +120,6 @@ namespace meteor
                 for (std::vector<uint8_t> &frame : mtvza_frames2)
                     mtvza_reader2.work(frame.data());
 
-                // BIS-M Deframing
-                {
-                    std::vector<uint8_t> bism_data;
-                    bism_data.insert(bism_data.end(), &cadu[7 - 1], &cadu[7 - 1] + 4);
-                    bism_data.insert(bism_data.end(), &cadu[263 - 1], &cadu[263 - 1] + 4);
-                    bism_data.insert(bism_data.end(), &cadu[519 - 1], &cadu[519 - 1] + 4);
-                    bism_data.insert(bism_data.end(), &cadu[775 - 1], &cadu[775 - 1] + 4);
-                    bism_frames = bism_deframer.work(bism_data.data(), bism_data.size());
-                }
-
-                // BIS-M Processing
-                // for (std::vector<uint8_t> &frame : bism_frames)
-                {
-                    // TODO
-                }
-
                 progress = data_in.tellg();
                 if (time(NULL) % 10 == 0 && lastTime != time(NULL))
                 {
@@ -184,9 +183,10 @@ namespace meteor
 
                 satdump::ImageProducts msumr_products;
                 msumr_products.instrument_name = "msu_mr";
+                msumr_products.bit_depth = 10;
                 msumr_products.has_timestamps = true;
                 msumr_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
-                msumr_products.set_tle(satdump::general_tle_registry.get_from_norad(norad));
+                msumr_products.set_tle(satdump::general_tle_registry.get_from_norad_time(norad, dataset.timestamp));
 
                 std::vector<double> filter_timestamps = msumr_timestamps;
                 double last = 0;
@@ -226,6 +226,34 @@ namespace meteor
                 for (int i = 0; i < 6; i++)
                     msumr_products.images.push_back({"MSU-MR-" + std::to_string(i + 1), std::to_string(i + 1), msumr_reader.getChannel(i)});
 
+                nlohmann::json calib_cfg;
+                calib_cfg["calibrator"] = "meteor_msumr";
+                calib_cfg["vars"]["lrpt"] = false;
+                calib_cfg["vars"]["views"] = msumr_reader.calibration_info;
+                calib_cfg["vars"]["temps"] = msu_mr_telemetry_calib;
+
+                msumr_products.set_calibration(calib_cfg);
+                msumr_products.set_calibration_type(0, satdump::ImageProducts::CALIB_REFLECTANCE);
+                msumr_products.set_calibration_type(1, satdump::ImageProducts::CALIB_REFLECTANCE);
+                msumr_products.set_calibration_type(2, satdump::ImageProducts::CALIB_REFLECTANCE);
+                msumr_products.set_calibration_type(3, satdump::ImageProducts::CALIB_RADIANCE);
+                msumr_products.set_calibration_type(4, satdump::ImageProducts::CALIB_RADIANCE);
+                msumr_products.set_calibration_type(5, satdump::ImageProducts::CALIB_RADIANCE);
+
+                msumr_products.set_wavenumber(0, 0);
+                msumr_products.set_wavenumber(1, 0);
+                msumr_products.set_wavenumber(2, 0);
+                msumr_products.set_wavenumber(3, 2695.9743);
+                msumr_products.set_wavenumber(4, 925.4075);
+                msumr_products.set_wavenumber(5, 839.8979);
+
+                msumr_products.set_calibration_default_radiance_range(0, 0, 1);
+                msumr_products.set_calibration_default_radiance_range(1, 0, 1);
+                msumr_products.set_calibration_default_radiance_range(2, 0, 1);
+                msumr_products.set_calibration_default_radiance_range(3, 0.05, 1);
+                msumr_products.set_calibration_default_radiance_range(4, 30, 120);
+                msumr_products.set_calibration_default_radiance_range(5, 30, 120);
+
                 saveJsonFile(directory + "/telemetry.json", msu_mr_telemetry);
                 msumr_products.save(directory);
                 dataset.products_list.push_back("MSU-MR");
@@ -252,7 +280,7 @@ namespace meteor
                 mtvza_products.instrument_name = "mtvza";
                 mtvza_products.has_timestamps = true;
                 mtvza_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
-                mtvza_products.set_tle(satdump::general_tle_registry.get_from_norad(norad));
+                mtvza_products.set_tle(satdump::general_tle_registry.get_from_norad_time(norad, dataset.timestamp));
                 mtvza_products.set_timestamps(mreader.timestamps);
 
                 if (msumr_serial_number == 2)
@@ -271,6 +299,23 @@ namespace meteor
                 mtvza_status = DONE;
             }
 
+            // BIS-M
+            {
+                logger->info("----------- BIS-M");
+                logger->info("Frames : %d", bism_reader.get_lines());
+
+#ifdef BISM_FULL_DUMP
+                bism_status = SAVING;
+                std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/BIS-M";
+
+                if (!std::filesystem::exists(directory))
+                    std::filesystem::create_directory(directory);
+
+                bism_reader.save(directory);
+#endif
+                bism_status = DONE;
+            }
+
             dataset.save(d_output_file_hint.substr(0, d_output_file_hint.rfind('/')));
         }
 
@@ -307,6 +352,14 @@ namespace meteor
                 ImGui::TableSetColumnIndex(2);
                 drawStatus(mtvza_status);
 
+                ImGui::TableNextRow();
+                ImGui::TableSetColumnIndex(0);
+                ImGui::Text("BIS-M");
+                ImGui::TableSetColumnIndex(1);
+                ImGui::TextColored(style::theme.green, "%d", bism_reader.get_lines());
+                ImGui::TableSetColumnIndex(2);
+                drawStatus(bism_status);
+
                 ImGui::EndTable();
             }
 
