@@ -18,8 +18,8 @@ namespace metop
 
         std::ifstream data_in;
         std::ofstream data_out;
-        std::atomic<size_t> filesize;
-        std::atomic<size_t> progress;
+        std::atomic<uint64_t> filesize;
+        std::atomic<uint64_t> progress;
 
         viterbi::Viterbi3_4 viterbi;
         deframing::BPSK_CCSDS_Deframer deframer;
