@@ -143,7 +143,7 @@ namespace noaa
                 dataset.satellite_name = sat_name;
                 dataset.timestamp = get_median(avhrr_reader.timestamps);
 
-                std::optional<satdump::TLE> satellite_tle = satdump::general_tle_registry.get_from_norad(norad);
+                std::optional<satdump::TLE> satellite_tle = satdump::general_tle_registry.get_from_norad_time(norad, dataset.timestamp);
 
                 // SATELLITE ID
                 {
@@ -254,13 +254,28 @@ namespace noaa
 
                     satdump::ImageProducts hirs_products;
                     hirs_products.instrument_name = "hirs";
-                    hirs_products.bit_depth = 13;
+                    hirs_products.bit_depth = 16;
                     hirs_products.set_tle(satellite_tle);
                     hirs_products.has_timestamps = true;
                     hirs_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
                     hirs_products.set_timestamps(hirs_reader.timestamps);
                     hirs_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/noaa_hirs.json")));
 
+                    nlohmann::json calib_coefs = loadJsonFile(resources::getResourcePath("calibration/HIRS.json"));
+                    if (calib_coefs.contains(sat_name))
+                    {
+                        hirs_reader.calibrate(calib_coefs[sat_name], sat_name == "NOAA-15");
+                        hirs_products.set_calibration(hirs_reader.calib_out);
+                        for (int n = 0; n < 19; n++)
+                            hirs_products.set_calibration_type(n, hirs_products.CALIB_RADIANCE);
+                        hirs_products.set_calibration_type(19, hirs_products.CALIB_REFLECTANCE);
+                            
+                        for (int c = 0; c < 20; c++)
+                            hirs_products.set_calibration_default_radiance_range(c, calib_coefs["all"]["default_display_range"][c][0].get<double>(), calib_coefs["all"]["default_display_range"][c][1].get<double>());
+                    }
+                    else
+                        logger->warn("(HIRS) Calibration data for " + sat_name + " not found. Calibration will not be performed");
+
                     for (int i = 0; i < 20; i++)
                         hirs_products.images.push_back({"HIRS-" + std::to_string(i + 1), std::to_string(i + 1), hirs_reader.getChannel(i)});
 
@@ -453,7 +468,7 @@ namespace noaa
                 dataset.satellite_name = sat_name;
                 dataset.timestamp = avg_overflowless_timestamps(timestamp_filtering::filter_timestamps_width_cfg(hirs_reader.timestamps, loadJsonFile(resources::getResourcePath("projections_settings/noaa_hirs.json"))));
 
-                std::optional<satdump::TLE> satellite_tle = satdump::general_tle_registry.get_from_norad(norad);
+                std::optional<satdump::TLE> satellite_tle = satdump::general_tle_registry.get_from_norad_time(norad, dataset.timestamp);
 
                 // SATELLITE ID
                 {
@@ -463,6 +478,7 @@ namespace noaa
                 }
 
                 // HIRS
+                /*
                 {
                     hirs_status = SAVING;
                     std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/HIRS";
@@ -490,6 +506,53 @@ namespace noaa
 
                     hirs_status = DONE;
                 }
+                */
+
+                {
+                    hirs_status = SAVING;
+                    std::string directory = d_output_file_hint.substr(0, d_output_file_hint.rfind('/')) + "/HIRS";
+
+                    if (!std::filesystem::exists(directory))
+                        std::filesystem::create_directories(directory);
+
+                    logger->info("----------- HIRS");
+                    logger->info("Lines : " + std::to_string(hirs_reader.line));
+
+                    if (hirs_reader.sync < hirs_reader.line * 28)
+                        logger->error("(HIRS) Possible filter wheel synchronization loss detected! Radiometric data may be invalid.");
+
+                    satdump::ImageProducts hirs_products;
+                    hirs_products.instrument_name = "hirs";
+                    hirs_products.bit_depth = 16;
+                    hirs_products.set_tle(satellite_tle);
+                    hirs_products.has_timestamps = true;
+                    hirs_products.timestamp_type = satdump::ImageProducts::TIMESTAMP_LINE;
+                    hirs_products.set_timestamps(hirs_reader.timestamps);
+                    hirs_products.set_proj_cfg(loadJsonFile(resources::getResourcePath("projections_settings/noaa_hirs.json")));
+
+                    nlohmann::json calib_coefs = loadJsonFile(resources::getResourcePath("calibration/HIRS.json"));
+                    if (calib_coefs.contains(sat_name))
+                    {
+                        hirs_reader.calibrate(calib_coefs[sat_name], sat_name == "NOAA-15");
+                        hirs_products.set_calibration(hirs_reader.calib_out);
+                        for (int n = 0; n < 19; n++)
+                            hirs_products.set_calibration_type(n, hirs_products.CALIB_RADIANCE);
+                        hirs_products.set_calibration_type(19, hirs_products.CALIB_REFLECTANCE);
+                            
+                        for (int c = 0; c < 20; c++)
+                            hirs_products.set_calibration_default_radiance_range(c, calib_coefs["all"]["default_display_range"][c][0].get<double>(), calib_coefs["all"]["default_display_range"][c][1].get<double>());
+                    }
+                    else
+                        logger->warn("(HIRS) Calibration data for " + sat_name + " not found. Calibration will not be performed");
+
+                    for (int i = 0; i < 20; i++)
+                        hirs_products.images.push_back({"HIRS-" + std::to_string(i + 1), std::to_string(i + 1), hirs_reader.getChannel(i)});
+
+                    hirs_products.save(directory);
+                    dataset.products_list.push_back("HIRS");
+
+                    hirs_status = DONE;
+                }
 
                 // SEM
                 {
