@@ -1,11 +1,11 @@
 #include "module_scisat1_instruments.h"
 #include <fstream>
-#include "common/ccsds/ccsds_standard/vcdu.h"
+#include "common/ccsds/ccsds_tm/vcdu.h"
 #include "logger.h"
 #include <filesystem>
 #include "imgui/imgui.h"
 #include "common/utils.h"
-#include "common/ccsds/ccsds_standard/demuxer.h"
+#include "common/ccsds/ccsds_tm/demuxer.h"
 #include "products/products.h"
 #include "products/dataset.h"
 #include "common/image/io.h"
@@ -30,9 +30,9 @@ namespace scisat1
             uint8_t cadu[1199];
 
             // Demuxers
-            ccsds::ccsds_standard::Demuxer demuxer_vcid0(1016, false, 2, 7);
-            ccsds::ccsds_standard::Demuxer demuxer_vcid1(1016, false, 2, 7);
-            ccsds::ccsds_standard::Demuxer demuxer_vcid4(1016, false, 2, 7);
+            ccsds::ccsds_tm::Demuxer demuxer_vcid0(1016, false, 2, 7);
+            ccsds::ccsds_tm::Demuxer demuxer_vcid1(1016, false, 2, 7);
+            ccsds::ccsds_tm::Demuxer demuxer_vcid4(1016, false, 2, 7);
 
             // std::ofstream output("file.ccsds");
 
@@ -47,7 +47,7 @@ namespace scisat1
                 data_in.read((char *)&cadu, 1199);
 
                 // Parse this transport frame
-                ccsds::ccsds_standard::VCDU vcdu = ccsds::ccsds_standard::parseVCDU(cadu);
+                ccsds::ccsds_tm::VCDU vcdu = ccsds::ccsds_tm::parseVCDU(cadu);
 
                 // logger->info(pkt.header.apid);
                 // logger->info(vcdu.vcid);
