@@ -9,6 +9,7 @@ void sdr_probe()
     // We don't wanna spam with init this time around
     logger->set_level(slog::LOG_ERROR);
     satdump::initSatdump();
+    completeLoggerInit();
     logger->set_level(slog::LOG_TRACE);
 
     dsp::registerAllSources();
@@ -22,7 +23,7 @@ void sdr_probe()
     {
         logger->info("- " + src.name);
         logger->debug("    - type : " + src.source_type);
-        logger->debug("    - id : %d", src.unique_id);
+        logger->debug("    - id : %s", src.unique_id.c_str());
     }
 
     logger->info("Found devices (sinks) :");
@@ -30,6 +31,6 @@ void sdr_probe()
     {
         logger->info("- " + src.name);
         logger->debug("    - type : " + src.sink_type);
-        logger->debug("    - id : %d", src.unique_id);
+        logger->debug("    - id : %s", src.unique_id.c_str());
     }
 }
