@@ -1,5 +1,7 @@
 #pragma once
 
+#include <typeindex>
+#include <optional>
 #include "nlohmann/json.hpp"
 
 /*
@@ -13,4 +15,4 @@ Switches :
  --switch
 This will set that parameter to true.
 */
-nlohmann::json parse_common_flags(int argc, char *argv[]);
\ No newline at end of file
+nlohmann::json parse_common_flags(int argc, char *argv[], std::map<std::string, std::optional<std::type_index>> strong_types = {});
\ No newline at end of file
