@@ -23,7 +23,11 @@ namespace dsp
         }
 
         mtx.lock();
+#if VOLK_VERSION >= 030100
+        volk_32fc_s32fc_x2_rotator2_32fc((lv_32fc_t *)output_stream->writeBuf, (lv_32fc_t *)input_stream->readBuf, (lv_32fc_t *)&phase_delta, (lv_32fc_t *)&phase, nsamples);
+#else
         volk_32fc_s32fc_x2_rotator_32fc((lv_32fc_t *)output_stream->writeBuf, (lv_32fc_t *)input_stream->readBuf, phase_delta, (lv_32fc_t *)&phase, nsamples);
+#endif
         mtx.unlock();
 
         input_stream->flush();
