@@ -43,7 +43,7 @@ namespace satdump
         {
             p = cfg;
         }
-        catch (std::exception &e)
+        catch (std::exception &)
         {
             proj_err = true;
         }
@@ -66,6 +66,8 @@ namespace satdump
 
 #include "manual_line_proj.h"
 
+#include "normal_line_xy_proj.h"
+
     std::shared_ptr<SatelliteProjection> get_sat_proj(nlohmann::ordered_json cfg, TLE tle, std::vector<double> timestamps_raw, bool allow_standard)
     {
         if (cfg.contains("timefilter"))
@@ -84,6 +86,9 @@ namespace satdump
         else if (cfg["type"].get<std::string>() == "manual_single_line")
             return std::make_shared<NormalLineManualSatProj>(cfg, tle, timestamps_raw);
 
+        else if (cfg["type"].get<std::string>() == "normal_single_xy_line")
+            return std::make_shared<NormalLineXYSatProj>(cfg, tle, timestamps_raw);
+
         // And plugins!
         std::vector<std::shared_ptr<SatelliteProjection>> projs;
         satdump::eventBus->fire_event<RequestSatProjEvent>({cfg["type"].get<std::string>(), projs, cfg, tle, timestamps_raw});
