@@ -8,6 +8,8 @@
 #include "core/config.h"
 #include "common/dsp_source_sink/format_notated.h"
 
+#include <curl/curl.h>
+
 void signed_soft_to_unsigned(int8_t *in, uint8_t *out, int nsamples)
 {
     for (int i = 0; i < nsamples; i++)
@@ -49,102 +51,190 @@ bool isStringPresent(std::string searched, std::string keyword)
     return found_it != std::string::npos;
 }
 
-#include <nng/nng.h>
-#include <nng/supplemental/http/http.h>
 #include "logger.h"
 #include "satdump_vars.h"
 
-#if defined(NNG_OPT_TLS_CONFIG)
-#include <nng/supplemental/tls/tls.h>
-#endif
-
-int perform_http_request(std::string url_str, std::string &result)
+size_t curl_write_std_string(void *contents, size_t size, size_t nmemb, std::string *s)
 {
-    nng_http_client *client;
-    nng_url *url;
-    nng_aio *aio;
-    nng_http_req *req;
-    nng_http_res *res;
-    int rv;
-
-    int return_val = 0;
-
-    if (((rv = nng_url_parse(&url, url_str.c_str())) != 0) ||
-        ((rv = nng_http_client_alloc(&client, url)) != 0))
+    size_t newLength = size * nmemb;
+    try
     {
-        if (rv == NNG_ENOTSUP)
-            logger->trace("Protocol not supported!");
-        return 1;
+        s->append((char *)contents, newLength);
     }
-
-// HTTPS
-#if defined(NNG_OPT_TLS_CONFIG)
-    nng_tls_config *tls_config;
-    nng_tls_config_alloc(&tls_config, NNG_TLS_MODE_CLIENT);
-    nng_tls_config_auth_mode(tls_config, NNG_TLS_AUTH_MODE_NONE);
-    nng_http_client_set_tls(client, tls_config);
-#endif
-
-    if (((rv = nng_http_req_alloc(&req, url)) != 0) ||
-        ((rv = nng_http_res_alloc(&res)) != 0) ||
-        ((rv = nng_aio_alloc(&aio, NULL, NULL)) != 0))
-        return 1;
-
-    nng_aio_set_timeout(aio, 30000);
-
-    nng_http_req_add_header(req, "User-Agent", std::string("SatDump/v" + (std::string)SATDUMP_VERSION).c_str());
-
-    // Start operation
-    nng_http_client_transact(client, req, res, aio);
-
-    if (nng_http_res_get_status(res) != NNG_HTTP_STATUS_OK)
+    catch (std::bad_alloc &)
     {
-        logger->trace("HTTP Server Responded: %d %s", nng_http_res_get_status(res), nng_http_res_get_reason(res));
-        return 1;
+        return 0;
     }
-
-    // Wait for it to complete.
-    nng_aio_wait(aio);
-
-    if ((rv = nng_aio_result(aio)) != 0)
-    {
-        logger->trace("HTTP Request Error! %s", nng_strerror(rv));
-        return_val = 1;
-    }
-
-    // Load result
-    char *data_ptr;
-    size_t data_sz = 0;
-    nng_http_res_get_data(res, (void **)&data_ptr, &data_sz);
-
-    result = std::string(data_ptr, &data_ptr[data_sz]);
-
-    // Free everything
-    nng_url_free(url);
-    nng_http_client_free(client);
-    nng_aio_free(aio);
-    nng_http_res_free(res);
-    nng_http_req_free(req);
-
-#if defined(NNG_OPT_TLS_CONFIG)
-    nng_tls_config_free(tls_config);
-#endif
-
-    return return_val;
+    return newLength;
 }
 
-std::string timestamp_to_string(double timestamp)
+int curl_float_progress_func(void *ptr, curl_off_t TotalToDownload, curl_off_t NowDownloaded, curl_off_t TotalToUpload, curl_off_t NowUploaded)
+{
+    float *pptr = (float *)ptr;
+    if (TotalToDownload != 0)
+        *pptr = (float)NowDownloaded / (float)TotalToDownload;
+    else if(TotalToUpload != 0)
+        *pptr = (float)NowUploaded / (float)TotalToUpload;
+    return 0;
+}
+
+int perform_http_request(std::string url_str, std::string &result, std::string added_header, float *progress)
+{
+    CURL *curl;
+    CURLcode res;
+    bool ret = 1;
+    char error_buffer[CURL_ERROR_SIZE] = {0};
+
+    curl_global_init(CURL_GLOBAL_ALL);
+
+    curl = curl_easy_init();
+    if (curl)
+    {
+        curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, error_buffer);
+        curl_easy_setopt(curl, CURLOPT_USERAGENT, std::string((std::string) "SatDump/v" + SATDUMP_VERSION).c_str());
+        curl_easy_setopt(curl, CURLOPT_URL, url_str.c_str());
+        curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, curl_write_std_string);
+        curl_easy_setopt(curl, CURLOPT_WRITEDATA, &result);
+        curl_easy_setopt(curl, CURLOPT_MAXREDIRS, 100);
+
+#ifdef CURLSSLOPT_NATIVE_CA
+        curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NATIVE_CA);
+#endif
+
+        struct curl_slist *chunk = NULL;
+        if (added_header != "")
+        {
+            /* Remove a header curl would otherwise add by itself */
+            chunk = curl_slist_append(chunk, added_header.c_str());
+            curl_easy_setopt(curl, CURLOPT_HTTPHEADER, chunk);
+        }
+
+        if (progress != nullptr)
+        {
+            curl_easy_setopt(curl, CURLOPT_XFERINFODATA, progress);
+            curl_easy_setopt(curl, CURLOPT_XFERINFOFUNCTION, curl_float_progress_func);
+            curl_easy_setopt(curl, CURLOPT_NOPROGRESS, false);
+        }
+
+        res = curl_easy_perform(curl);
+
+        if (res != CURLE_OK)
+        {
+            if (strlen(error_buffer))
+                logger->error("curl_easy_perform() failed: %s", error_buffer);
+            else
+                logger->error("curl_easy_perform() failed: %s", curl_easy_strerror(res));
+        }
+        else
+            ret = 0;
+
+        curl_easy_cleanup(curl);
+
+        if (chunk != NULL)
+            curl_slist_free_all(chunk);
+    }
+    curl_global_cleanup();
+    return ret;
+}
+
+int perform_http_request_post(std::string url_str, std::string &result, std::string post_req, std::string added_header)
+{
+    CURL *curl;
+    CURLcode res;
+    bool ret = 1;
+    char error_buffer[CURL_ERROR_SIZE] = {0};
+
+    curl_global_init(CURL_GLOBAL_ALL);
+
+    curl = curl_easy_init();
+    if (curl)
+    {
+        curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, error_buffer);
+        curl_easy_setopt(curl, CURLOPT_USERAGENT, std::string((std::string) "SatDump/v" + SATDUMP_VERSION).c_str());
+        curl_easy_setopt(curl, CURLOPT_URL, url_str.c_str());
+        curl_easy_setopt(curl, CURLOPT_POSTFIELDS, post_req.c_str());
+        curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, curl_write_std_string);
+        curl_easy_setopt(curl, CURLOPT_WRITEDATA, &result);
+
+#ifdef CURLSSLOPT_NATIVE_CA
+        curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NATIVE_CA);
+#endif
+
+        struct curl_slist *chunk = NULL;
+        if (added_header != "")
+        {
+            /* Remove a header curl would otherwise add by itself */
+            chunk = curl_slist_append(chunk, added_header.c_str());
+            curl_easy_setopt(curl, CURLOPT_HTTPHEADER, chunk);
+        }
+
+        res = curl_easy_perform(curl);
+
+        if (res != CURLE_OK)
+        {
+            if (strlen(error_buffer))
+                logger->error("curl_easy_perform() failed: %s", error_buffer);
+            else
+                logger->error("curl_easy_perform() failed: %s", curl_easy_strerror(res));
+        }
+        else
+            ret = 0;
+
+        curl_easy_cleanup(curl);
+
+        if (chunk != NULL)
+            curl_slist_free_all(chunk);
+    }
+    curl_global_cleanup();
+    return ret;
+}
+
+std::string timestamp_to_string(double timestamp, bool local)
 {
     if (timestamp < 0)
         timestamp = 0;
+
     time_t tttime = timestamp;
-    std::tm *timeReadable = gmtime(&tttime);
-    return std::to_string(timeReadable->tm_year + 1900) + "/" +
-           (timeReadable->tm_mon + 1 > 9 ? std::to_string(timeReadable->tm_mon + 1) : "0" + std::to_string(timeReadable->tm_mon + 1)) + "/" +
-           (timeReadable->tm_mday > 9 ? std::to_string(timeReadable->tm_mday) : "0" + std::to_string(timeReadable->tm_mday)) + " " +
-           (timeReadable->tm_hour > 9 ? std::to_string(timeReadable->tm_hour) : "0" + std::to_string(timeReadable->tm_hour)) + ":" +
-           (timeReadable->tm_min > 9 ? std::to_string(timeReadable->tm_min) : "0" + std::to_string(timeReadable->tm_min)) + ":" +
-           (timeReadable->tm_sec > 9 ? std::to_string(timeReadable->tm_sec) : "0" + std::to_string(timeReadable->tm_sec));
+    std::tm *timeReadable = (local ? localtime(&tttime) : gmtime(&tttime));
+    std::stringstream timestamp_string;
+    std::string timezone_string = "";
+
+    if (local)
+    {
+#ifdef _WIN32
+        size_t tznameSize = 0;
+        char *tznameBuffer = NULL;
+        timezone_string = " ";
+        _get_tzname(&tznameSize, NULL, 0, timeReadable->tm_isdst);
+        if (tznameSize > 0)
+        {
+            if (nullptr != (tznameBuffer = (char *)(malloc(tznameSize))))
+            {
+                if (_get_tzname(&tznameSize, tznameBuffer, tznameSize, timeReadable->tm_isdst) == 0)
+                    for (size_t i = 0; i < tznameSize; i++)
+                        if (std::isupper(tznameBuffer[i]))
+                            timezone_string += tznameBuffer[i];
+
+                free(tznameBuffer);
+            }
+        }
+        if (timezone_string == " ")
+            timezone_string = " Local";
+#else
+        timezone_string = " " + std::string(timeReadable->tm_zone);
+#endif
+    }
+
+    timestamp_string << std::setfill('0')
+                     << timeReadable->tm_year + 1900 << "/"
+                     << std::setw(2) << timeReadable->tm_mon + 1 << "/"
+                     << std::setw(2) << timeReadable->tm_mday << " "
+                     << std::setw(2) << timeReadable->tm_hour << ":"
+                     << std::setw(2) << timeReadable->tm_min << ":"
+                     << std::setw(2) << timeReadable->tm_sec
+                     << timezone_string;
+
+    return timestamp_string.str();
 }
 
 double get_median(std::vector<double> values)
