@@ -11,6 +11,10 @@
 #include <optional>
 #include <chrono>
 
+#ifdef _MSC_VER
+#define timegm _mkgmtime
+#endif
+
 void char_array_to_uchar(int8_t *in, uint8_t *out, int nsamples);
 void signed_soft_to_unsigned(int8_t *in, uint8_t *out, int nsamples);
 
@@ -126,10 +130,16 @@ bool isStringPresent(std::string searched, std::string keyword);
 // Return filesize
 uint64_t getFilesize(std::string filepath);
 
-// Perform a HTTP Request on the provided URL and return the result as a string
-int perform_http_request(std::string url, std::string &result);
+// cURL helper function
+size_t curl_write_std_string(void* contents, size_t size, size_t nmemb, std::string* s);
 
-std::string timestamp_to_string(double timestamp);
+// Perform a HTTP Request on the provided URL and return the result as a string
+int perform_http_request(std::string url, std::string &result, std::string added_header = "", float *progress = nullptr);
+
+// Perform a HTTP Request on the provided URL and return the result as a string, with POST data
+int perform_http_request_post(std::string url_str, std::string &result, std::string post_req, std::string added_header = "");
+
+std::string timestamp_to_string(double timestamp, bool local = false);
 
 inline std::vector<float> double_buffer_to_float(double *ptr, int size)
 {
@@ -141,8 +151,6 @@ inline std::vector<float> double_buffer_to_float(double *ptr, int size)
 
 double get_median(std::vector<double> values);
 
-extern "C" time_t mktime_utc(const struct tm *timeinfo_utc); // Already in libpredict!
-
 template <typename T>
 std::vector<uint8_t> unsigned_to_bitvec(T v)
 {
