@@ -2,6 +2,8 @@
 
 #include "imgui/imgui.h"
 #include <mutex>
+#include "common/image/image.h"
+#include <string>
 
 namespace widgets
 {
@@ -25,7 +27,9 @@ namespace widgets
 
     public:
         FFTPlot(float *v, int size, float min, float max, float scale_res = 20);
+
         void draw(ImVec2 size);
+        image::Image drawImg(int size_x, int size_y);
 
         void set_size(int size)
         {
@@ -33,5 +37,7 @@ namespace widgets
             values_size = size;
             work_mutex.unlock();
         }
+
+        std::vector<std::pair<std::string, double>> vfo_freqs;
     };
 }
\ No newline at end of file
