@@ -75,9 +75,9 @@ void loadPlugins(std::map<std::string, std::shared_ptr<satdump::Plugin>> &loaded
                 goto skip_this;
 
 #ifdef __ANDROID__
-            if (path.find("libandroid_imgui.so") != std::string::npos)
-                goto skip_this;
-            if (path.find("libsatdump_core.so") != std::string::npos)
+            if (path.find("libandroid_imgui.so") != std::string::npos ||
+                path.find("libsatdump_core.so") != std::string::npos ||
+                path.find("libsatdump_interface.so") != std::string::npos)
                 goto skip_this;
 #endif
             try
@@ -106,4 +106,4 @@ void loadPlugins(std::map<std::string, std::shared_ptr<satdump::Plugin>> &loaded
         else
             logger->warn("No Plugins in " + plugins_path + "!");
     }
-}
\ No newline at end of file
+}
