@@ -7,7 +7,6 @@
 #include "nlohmann/json_utils.h"
 #include "logger.h"
 #include "config.h"
-#include "module.h"
 #include "backend.h"
 #include "resources.h"
 
@@ -15,6 +14,9 @@
 #include <CoreGraphics/CGDirectDisplay.h>
 #endif
 
+SATDUMP_DLL float ui_scale = 1;                 // UI Scaling factor, set to 1 (no scaling) by default
+SATDUMP_DLL int demod_constellation_size = 200; // Demodulator constellation size
+
 namespace style
 {
     SATDUMP_DLL Theme theme;
@@ -232,6 +234,7 @@ namespace style
                 {"widget_bg", &Theme::widget_bg},
                 {"frame_bg", &Theme::frame_bg},
                 {"overlay_bg", &Theme::overlay_bg},
+                {"notification_bg", &Theme::notification_bg},
                 {"freq_highlight", &Theme::freq_highlight}
             };
 
@@ -277,8 +280,8 @@ namespace style
         ImGuiIO &io = ImGui::GetIO();
         io.Fonts->Clear();
         const ImWchar def[] = {0x20, 0x2300, 0}; //default range
-        const ImWchar list[6][3] = { {0xf000, 0xf0ff, 0}, {0xf400, 0xf4ff, 0}, {0xf800, 0xf8ff, 0},
-            {0xfc00, 0xfcff, 0}, {0xea00, 0xeaff, 0}, {0xf200, 0xf2ff, 0} };
+        const ImWchar list[7][3] = { {0xf000, 0xf0ff, 0}, {0xf400, 0xf4ff, 0}, {0xf800, 0xf8ff, 0},
+            {0xfc00, 0xfcff, 0}, {0xea00, 0xeaff, 0}, {0xf200, 0xf2ff, 0} , {0x2000, 0x20ff, 0}};
         static ImFontConfig config;
         float macos_fbs = macos_framebuffer_scale();
         float font_scaling = dpi_scaling * macos_fbs;
@@ -286,7 +289,7 @@ namespace style
         baseFont = io.Fonts->AddFontFromFileTTF(resources::getResourcePath("fonts/" + theme.font + ".ttf").c_str(), theme.font_size * font_scaling, &config, def);
         config.MergeMode = true;
 
-        for (int i = 0; i < 6; i++)
+        for (int i = 0; i < 7; i++)
             baseFont = io.Fonts->AddFontFromFileTTF(resources::getResourcePath("fonts/font.ttf").c_str(), theme.font_size * font_scaling, &config, list[i]);
         config.MergeMode = false;
 
