@@ -4,7 +4,7 @@
 class FileSelectWidget
 {
 public:
-    FileSelectWidget(std::string label, std::string selection_text, bool directory = false);
+    FileSelectWidget(std::string label, std::string selection_text, bool directory = false, bool allow_url = false);
     ~FileSelectWidget();
     bool draw(std::string hint = "");
     bool isValid();
@@ -14,8 +14,8 @@ public:
 
 private:
     std::string label, selection_text, id, btnid, default_dir, path;
-    bool directory, waiting_for_res;
+    bool directory, waiting_for_res, allow_url;
     pfd::open_file *fileselect;
     pfd::select_folder *dirselect;
-    bool file_valid;
+    bool file_valid, url_valid;
 };
