@@ -336,13 +336,14 @@ namespace ccsds
         ImGui::BeginGroup();
         {
             // Constellation
+            ImDrawList* draw_list = ImGui::GetWindowDrawList();
+            ImVec2 rect_min = ImGui::GetCursorScreenPos();
+            ImVec2 rect_max = { rect_min.x + 200 * ui_scale, rect_min.y + 200 * ui_scale };
+            draw_list->AddRectFilled(rect_min, rect_max, style::theme.widget_bg);
+            draw_list->PushClipRect(rect_min, rect_max);
+
             if (d_constellation == dsp::BPSK)
             {
-                ImDrawList *draw_list = ImGui::GetWindowDrawList();
-                draw_list->AddRectFilled(ImGui::GetCursorScreenPos(),
-                                         ImVec2(ImGui::GetCursorScreenPos().x + 200 * ui_scale, ImGui::GetCursorScreenPos().y + 200 * ui_scale),
-                                         style::theme.widget_bg);
-
                 for (int i = 0; i < 2048; i++)
                 {
                     draw_list->AddCircleFilled(ImVec2(ImGui::GetCursorScreenPos().x + (int)(100 * ui_scale + (((int8_t *)soft_buffer)[i] / 127.0) * 130 * ui_scale) % int(200 * ui_scale),
@@ -350,16 +351,9 @@ namespace ccsds
                                                2 * ui_scale,
                                                style::theme.constellation);
                 }
-
-                ImGui::Dummy(ImVec2(200 * ui_scale + 3, 200 * ui_scale + 3));
             }
             else
             {
-                ImDrawList *draw_list = ImGui::GetWindowDrawList();
-                draw_list->AddRectFilled(ImGui::GetCursorScreenPos(),
-                                         ImVec2(ImGui::GetCursorScreenPos().x + 200 * ui_scale, ImGui::GetCursorScreenPos().y + 200 * ui_scale),
-                                         style::theme.widget_bg);
-
                 for (int i = 0; i < 2048; i++)
                 {
                     draw_list->AddCircleFilled(ImVec2(ImGui::GetCursorScreenPos().x + (int)(100 * ui_scale + (((int8_t *)soft_buffer)[i * 2 + 0] / 127.0) * 100 * ui_scale) % int(200 * ui_scale),
@@ -367,9 +361,10 @@ namespace ccsds
                                                2 * ui_scale,
                                                style::theme.constellation);
                 }
-
-                ImGui::Dummy(ImVec2(200 * ui_scale + 3, 200 * ui_scale + 3));
             }
+
+            draw_list->PopClipRect();
+            ImGui::Dummy(ImVec2(200 * ui_scale + 3, 200 * ui_scale + 3));
         }
         ImGui::EndGroup();
 
