@@ -4,6 +4,10 @@
 #include "logger.h"
 #include "processing.h"
 
+#ifndef _MSC_VER
+#include <sys/statvfs.h>
+#endif
+
 namespace satdump
 {
     nlohmann::json RecorderApplication::serialize_config()
@@ -16,13 +20,17 @@ namespace satdump
         out["fft_rate"] = fft_rate;
         out["waterfall_rate"] = waterfall_rate;
         out["waterfall_palette"] = waterfall_palettes[selected_waterfall_palette].name;
-        out["select_sample_format"] = select_sample_format;
+        out["baseband_type"] = (std::string)baseband_format;
         if (fft_plot && waterfall_plot && fft)
         {
             out["fft_min"] = fft_plot->scale_min;
             out["fft_max"] = fft_plot->scale_max;
             out["fft_avgn"] = fft->avg_num;
         }
+
+#if defined(BUILD_ZIQ) || defined(BUILD_ZIQ2)
+        out["ziq_depth"] = baseband_format.ziq_depth;
+#endif
         return out;
     }
 
@@ -51,8 +59,8 @@ namespace satdump
             fft_rate = in["fft_rate"];
         if (in.contains("waterfall_rate"))
             waterfall_rate = in["waterfall_rate"];
-        if (in.contains("select_sample_format"))
-            select_sample_format = in["select_sample_format"];
+        if (in.contains("baseband_type"))
+            baseband_format = in["baseband_type"].get<std::string>();
         if (in.contains("waterfall_palette"))
         {
             std::string name = in["waterfall_palette"].get<std::string>();
@@ -61,6 +69,10 @@ namespace satdump
                     selected_waterfall_palette = i;
             waterfall_plot->set_palette(waterfall_palettes[selected_waterfall_palette]);
         }
+#if defined(BUILD_ZIQ) || defined(BUILD_ZIQ2)
+        if (in.contains("ziq_depth"))
+            baseband_format.ziq_depth = in["ziq_depth"];
+#endif
     }
 
     void RecorderApplication::start()
@@ -125,7 +137,7 @@ namespace satdump
         {
             if (config::main_cfg["user"]["recorder_sdr_settings"].contains(sources[sdr_select_id].name))
             {
-                auto cfg = config::main_cfg["user"]["recorder_sdr_settings"][sources[sdr_select_id].name];
+                auto &cfg = config::main_cfg["user"]["recorder_sdr_settings"][sources[sdr_select_id].name];
                 source_ptr->set_settings(cfg);
                 if (cfg.contains("samplerate"))
                 {
@@ -154,65 +166,6 @@ namespace satdump
         }
     }
 
-    void RecorderApplication::set_output_sample_format()
-    {
-        int type_lut[] = {
-            0,
-            1,
-            2,
-            3,
-#ifdef BUILD_ZIQ
-            4,
-            5,
-            6,
-#endif
-#ifdef BUILD_ZIQ2
-            7,
-            8,
-#endif
-        };
-
-        int f = type_lut[select_sample_format];
-
-        if (f == 0)
-            file_sink->set_output_sample_type(dsp::CF_32);
-        else if (f == 1)
-            file_sink->set_output_sample_type(dsp::CS_16);
-        else if (f == 2)
-            file_sink->set_output_sample_type(dsp::CS_8);
-        else if (f == 3)
-            file_sink->set_output_sample_type(dsp::WAV_16);
-#ifdef BUILD_ZIQ
-        else if (f == 4)
-        {
-            file_sink->set_output_sample_type(dsp::ZIQ);
-            ziq_bit_depth = 8;
-        }
-        else if (f == 5)
-        {
-            file_sink->set_output_sample_type(dsp::ZIQ);
-            ziq_bit_depth = 16;
-        }
-        else if (f == 6)
-        {
-            file_sink->set_output_sample_type(dsp::ZIQ);
-            ziq_bit_depth = 32;
-        }
-#endif
-#ifdef BUILD_ZIQ2
-        else if (f == 7)
-        {
-            file_sink->set_output_sample_type(dsp::ZIQ2);
-            ziq_bit_depth = 8;
-        }
-        else if (f == 8)
-        {
-            file_sink->set_output_sample_type(dsp::ZIQ2);
-            ziq_bit_depth = 16;
-        }
-#endif
-    }
-
     void RecorderApplication::start_processing()
     {
         if (pipeline_selector.outputdirselect.isValid() || automated_live_output_dir)
@@ -224,18 +177,14 @@ namespace satdump
             pipeline_params["buffer_size"] = dsp::STREAM_BUFFER_SIZE; // This is required, as we WILL go over the (usually) default 8192 size
             pipeline_params["start_timestamp"] = (double)time(0);     // Some pipelines need this
 
-            if (automated_live_output_dir)
-            {
-                pipeline_output_dir = prepareAutomatedPipelineFolder(time(0), source_ptr->d_frequency, pipelines[pipeline_selector.pipeline_id].name);
-            }
-            else
-            {
-                pipeline_output_dir = pipeline_selector.outputdirselect.getPath();
-            }
-
             try
             {
-                live_pipeline = std::make_unique<LivePipeline>(pipelines[pipeline_selector.pipeline_id], pipeline_params, pipeline_output_dir);
+                if (automated_live_output_dir)
+                    pipeline_output_dir = prepareAutomatedPipelineFolder(time(0), source_ptr->d_frequency, pipeline_selector.selected_pipeline.name);
+                else
+                    pipeline_output_dir = pipeline_selector.outputdirselect.getPath();
+
+                live_pipeline = std::make_unique<LivePipeline>(pipeline_selector.selected_pipeline, pipeline_params, pipeline_output_dir);
                 splitter->reset_output("live");
                 live_pipeline->start(splitter->get_output("live"), ui_thread_pool);
                 splitter->set_enabled("live", true);
@@ -258,19 +207,20 @@ namespace satdump
     {
         if (is_processing)
         {
+            is_stopping_processing = true;
             logger->trace("Stop pipeline...");
-            is_processing = false;
             splitter->set_enabled("live", false);
             live_pipeline->stop();
+            is_stopping_processing = is_processing = false;
 
             if (config::main_cfg["user_interface"]["finish_processing_after_live"]["value"].get<bool>() && live_pipeline->getOutputFiles().size() > 0)
             {
-                Pipeline pipeline = pipelines[pipeline_selector.pipeline_id];
+                Pipeline pipeline = pipeline_selector.selected_pipeline;
                 std::string input_file = live_pipeline->getOutputFiles()[0];
                 int start_level = pipeline.live_cfg.normal_live[pipeline.live_cfg.normal_live.size() - 1].first;
                 std::string input_level = pipeline.steps[start_level].level_name;
                 ui_thread_pool.push([=](int)
-                                    { processing::process(pipeline.name, input_level, input_file, pipeline_output_dir, pipeline_params); });
+                                    { processing::process(pipeline, input_level, input_file, pipeline_output_dir, pipeline_params); });
             }
 
             live_pipeline.reset();
@@ -280,20 +230,9 @@ namespace satdump
     void RecorderApplication::start_recording()
     {
         splitter->set_enabled("record", true);
-
-        std::string recording_path = config::main_cfg["satdump_directories"]["recording_path"]["value"].get<std::string>();
-#if defined(_MSC_VER)
-        recording_path += "\\";
-#elif defined(__ANDROID__)
-        if (recording_path == ".")
-            recording_path = "/storage/emulated/0";
-        recording_path += "/";
-#else
-        recording_path += "/";
-#endif
-
+        load_rec_path_data();
         std::string filename = recording_path + prepareBasebandFileName(getTime(), get_samplerate(), frequency_hz);
-        recorder_filename = file_sink->start_recording(filename, get_samplerate(), ziq_bit_depth);
+        recorder_filename = file_sink->start_recording(filename, get_samplerate());
         logger->info("Recording to " + recorder_filename);
         is_recording = true;
     }
@@ -306,9 +245,34 @@ namespace satdump
             splitter->set_enabled("record", false);
             recorder_filename = "";
             is_recording = false;
+            load_rec_path_data();
         }
     }
 
+    void RecorderApplication::load_rec_path_data()
+    {
+        recording_path = config::main_cfg["satdump_directories"]["recording_path"]["value"].get<std::string>();
+#if defined(_MSC_VER)
+        recording_path += "\\";
+#elif defined(__ANDROID__)
+        if (recording_path == ".")
+            recording_path = "/storage/emulated/0";
+        recording_path += "/";
+#else
+        recording_path += "/";
+#endif
+
+#ifdef _MSC_VER
+        ULARGE_INTEGER bytes_available;
+        if (GetDiskFreeSpaceEx(recording_path.c_str(), &bytes_available, NULL, NULL))
+            disk_available = bytes_available.QuadPart;
+#else
+        struct statvfs stat_buffer;
+        if (statvfs(recording_path.c_str(), &stat_buffer) == 0)
+            disk_available = stat_buffer.f_bavail * stat_buffer.f_bsize;
+#endif
+    }
+
     void RecorderApplication::try_init_tracking_widget()
     {
         if (tracking_widget == nullptr)
@@ -341,7 +305,7 @@ namespace satdump
                             if (satdump::general_tle_registry.get_from_norad(obj.norad).has_value())
                                 name = satdump::general_tle_registry.get_from_norad(obj.norad)->name;
                             name += " - " + format_notated(dl.frequency, "Hz");
-                            add_vfo_live(id, name, dl.frequency, dl.pipeline_selector->pipeline_id, dl.pipeline_selector->getParameters());
+                            add_vfo_live(id, name, dl.frequency, dl.pipeline_selector->selected_pipeline, dl.pipeline_selector->getParameters());
                         }
 
                         if (dl.record)
@@ -351,7 +315,7 @@ namespace satdump
                             if (satdump::general_tle_registry.get_from_norad(obj.norad).has_value())
                                 name = satdump::general_tle_registry.get_from_norad(obj.norad)->name;
                             name += " - " + format_notated(dl.frequency, "Hz");
-                            add_vfo_reco(id, name, dl.frequency, dsp::basebandTypeFromString(dl.baseband_format), dl.baseband_decimation);
+                            add_vfo_reco(id, name, dl.frequency, dl.baseband_format, dl.baseband_decimation);
                         }
                     }
                 }
@@ -380,14 +344,15 @@ namespace satdump
 
                     if (obj.downlinks[0].live)
                     {
-                        pipeline_selector.select_pipeline(pipelines[obj.downlinks[0].pipeline_selector->pipeline_id].name);
+                        pipeline_selector.select_pipeline(obj.downlinks[0].pipeline_selector->selected_pipeline.name);
                         pipeline_selector.setParameters(obj.downlinks[0].pipeline_selector->getParameters());
+                        pipeline_selector.selected_pipeline.steps = obj.downlinks[0].pipeline_selector->selected_pipeline.steps;
                         start_processing();
                     }
 
                     if (obj.downlinks[0].record)
                     {
-                        // file_sink->set_output_sample_type(dsp::basebandTypeFromString(obj.downlinks[0].baseband_format));
+                        file_sink->set_output_sample_type(obj.downlinks[0].baseband_format);
                         start_recording();
                     }
                 }
