@@ -9,9 +9,7 @@
 #include <functional>
 #include "core/config.h"
 #include "nlohmann/json_utils.h"
-
-#include "common/tracking/obj_tracker/object_tracker.h"
-#include "common/tracking/scheduler/scheduler.h"
+#include "import_export.h"
 
 namespace satdump
 {
@@ -22,6 +20,9 @@ namespace satdump
         double qth_lat = 0;
         double qth_alt = 0;
 
+    private: // Config Exporter
+        TrackingImportExport config_import_export;
+
     public: // Handlers
         std::function<void(AutoTrackCfg, SatellitePass, TrackedObject)> aos_callback = [](AutoTrackCfg, SatellitePass, TrackedObject) {};
         std::function<void(AutoTrackCfg, SatellitePass, TrackedObject)> los_callback = [](AutoTrackCfg, SatellitePass, TrackedObject) {};
@@ -31,6 +32,8 @@ namespace satdump
         AutoTrackScheduler auto_scheduler;
 
         std::shared_ptr<rotator::RotatorHandler> rotator_handler;
+        std::vector<rotator::RotatorHandlerOption> rotator_options;
+        std::string rotator_options_str;
         int selected_rotator_handler = 0;
 
         bool config_window_was_asked = false, show_window_config = false;
