@@ -11,6 +11,7 @@
 #include "init.h"
 #include "common/tracking/tle.h"
 #include "common/widgets/timed_message.h"
+#include "common/widgets/json_editor.h"
 
 #include "core/style.h"
 
@@ -37,6 +38,7 @@ namespace satdump
         char tle_last_update[80];
 
         bool show_imgui_demo = false;
+        bool advanced_mode = false;
 
         widgets::TimedMessage saved_message;
 
@@ -84,6 +86,8 @@ namespace satdump
                 theme_id++;
             }
 
+            advanced_mode = getValueOrDefault(satdump::config::main_cfg["user_interface"]["advanced_mode"]["value"], false);
+
 #ifdef USE_OPENCL
             opencl_devices_enum = opencl::getAllDevices();
             opencl_devices_enum.push_back({ -1, -1, "None (Use CPU)" });
@@ -104,6 +108,7 @@ namespace satdump
 
         void render()
         {
+            ImGui::SeparatorText("Core Settings");
             if (ImGui::CollapsingHeader("User Interface"))
             {
                 if (ImGui::BeginTable("##satdumpuisettings", 2, ImGuiTableFlags_Borders | ImGuiTableFlags_RowBg))
@@ -194,7 +199,7 @@ namespace satdump
                 }
             }
 
-            if (ImGui::CollapsingHeader("Output Directories"))
+            if (ImGui::CollapsingHeader("File Input/Output"))
             {
                 if (ImGui::BeginTable("##satdumpoutput_directories", 2, ImGuiTableFlags_Borders | ImGuiTableFlags_RowBg))
                 {
@@ -204,14 +209,53 @@ namespace satdump
                 }
             }
 
-            for (auto &plugin_hdl : config::plugin_config_handlers)
+            if (config::plugin_config_handlers.size() > 0)
             {
-                if (ImGui::CollapsingHeader(plugin_hdl.name.c_str()))
+                ImGui::SetCursorPosY(ImGui::GetCursorPosY() + 10 * ui_scale);
+                ImGui::SeparatorText("Plugin Settings");
+                for (auto &plugin_hdl : config::plugin_config_handlers)
                 {
-                    plugin_hdl.render();
+                    if (ImGui::CollapsingHeader(plugin_hdl.name.c_str()))
+                    {
+                        plugin_hdl.render();
+                    }
                 }
             }
 
+            if (advanced_mode)
+            {
+                ImGui::SetCursorPosY(ImGui::GetCursorPosY() + 10 * ui_scale);
+                ImGui::SeparatorText("Advanced Settings");
+                if (ImGui::CollapsingHeader("TLE Settings"))
+                {
+                    widgets::JSONTreeEditor(satdump::config::main_cfg["tle_settings"], "tle_settings", false);
+                    if (ImGui::Button("Reset##tle_settings"))
+                        satdump::config::main_cfg["tle_settings"] = satdump::config::master_cfg["tle_settings"];
+                }
+                if (ImGui::CollapsingHeader("Advanced Settings"))
+                {
+                    widgets::JSONTreeEditor(satdump::config::main_cfg["advanced_settings"], "advanced_settings");
+                    ImGui::SameLine();
+                    if (ImGui::Button("Reset##advanced_settings"))
+                        satdump::config::main_cfg["advanced_settings"] = satdump::config::master_cfg["advanced_settings"];
+                }
+                if (ImGui::CollapsingHeader("Instrument Config"))
+                {
+                    widgets::JSONTreeEditor(satdump::config::main_cfg["viewer"]["instruments"], "instrument_settings");
+                    ImGui::SameLine();
+                    if (ImGui::Button("Reset##instrument_settings"))
+                        satdump::config::main_cfg["viewer"]["instruments"] = satdump::config::master_cfg["viewer"]["instruments"];
+                }
+                if (ImGui::CollapsingHeader("Default Pipeline Configs"))
+                {
+                    widgets::JSONTreeEditor(pipelines_json, "pipelines");
+                    ImGui::SameLine();
+                    if (ImGui::Button("Reset##pipelines"))
+                        pipelines_json = pipelines_system_json;
+                }
+            }
+
+            ImGui::SetCursorPosY(ImGui::GetCursorPosY() + 5 * ui_scale);
             if (ImGui::Button("Save"))
             {
 #ifdef USE_OPENCL
@@ -233,6 +277,9 @@ namespace satdump
                     plugin_hdl.save();
 
                 config::saveUserConfig();
+                if (advanced_mode)
+                    savePipelines();
+                advanced_mode = getValueOrDefault(satdump::config::main_cfg["user_interface"]["advanced_mode"]["value"], false);
                 saved_message.set_message(style::theme.green, "Settings saved");
                 satdump::update_ui = true;
             }
