@@ -39,11 +39,15 @@ namespace satdump
 
     class ViewerApplication : public Application
     {
+    public:
+        struct RenderLoadMenuElementsEvent
+        {
+        };
+
     protected:
         const std::string app_id;
         virtual void drawUI();
 
-        bool dragging_panel = false;
         float panel_ratio = 0.23;
         float last_width = -1.0f;
 
@@ -164,6 +168,11 @@ namespace satdump
 
             out["projections_current_selected_proj"] = projections_current_selected_proj;
 
+            out["projection_auto_mode"] = projection_auto_mode;
+            out["projection_auto_scale_mode"] = projection_auto_scale_mode;
+            out["projection_autoscale_x"] = projection_autoscale_x;
+            out["projection_autoscale_y"] = projection_autoscale_y;
+
             out["projections_equirectangular_tl_lon"] = projections_equirectangular_tl_lon;
             out["projections_equirectangular_tl_lat"] = projections_equirectangular_tl_lat;
             out["projections_equirectangular_br_lon"] = projections_equirectangular_br_lon;
@@ -201,6 +210,11 @@ namespace satdump
 
             setValueIfExists(in["projections_current_selected_proj"], projections_current_selected_proj);
 
+            setValueIfExists(in["projection_auto_mode"], projection_auto_mode);
+            setValueIfExists(in["projection_auto_scale_mode"], projection_auto_scale_mode);
+            setValueIfExists(in["projection_autoscale_x"], projection_autoscale_x);
+            setValueIfExists(in["projection_autoscale_y"], projection_autoscale_y);
+
             setValueIfExists(in["projections_equirectangular_tl_lon"], projections_equirectangular_tl_lon);
             setValueIfExists(in["projections_equirectangular_tl_lat"], projections_equirectangular_tl_lat);
             setValueIfExists(in["projections_equirectangular_br_lon"], projections_equirectangular_br_lon);
@@ -238,6 +252,7 @@ namespace satdump
 
     public:
         static std::string getID() { return "viewer"; }
+        std::string get_name() { return "Viewer"; }
         static std::shared_ptr<Application> getInstance() { return std::make_shared<ViewerApplication>(); }
     };
 };
\ No newline at end of file
